@@ -3,12 +3,12 @@ package inc::MBX::Alien::FLTK::Utility;
     use strict;
     use warnings;
     use Config qw[%Config];
-    use File::Spec::Functions qw[splitpath catpath catdir rel2abs];
+    use File::Spec::Functions qw[splitpath catpath catdir rel2abs canonpath];
     use File::Basename qw[];
-    use Cwd qw[];
+    use File::Find qw[find];
     use Exporter qw[import];
     our @EXPORT_OK
-        = qw[can_run run _o _a _exe _dll _path _realpath _abs _rel _dir _file _split _cwd];
+        = qw[can_run run _o _a _exe _dll find_h find_lib _path _abs _rel _dir _file _split];
 
     sub can_run {    # Snagged from IPC::CMD and trimmed for my use
         my ($prog) = @_;
@@ -21,13 +21,11 @@ package inc::MBX::Alien::FLTK::Utility;
             return $prog if scalar $syms->getsym(uc $prog);
         }
         require ExtUtils::MM;
-        my @possible;
         for my $dir ((split /\Q$Config{path_sep}\E/, $ENV{PATH}),
                      File::Spec->curdir)
         {   my $abs = File::Spec->catfile($dir, $prog);
-            push @possible, $abs if $abs = MM->maybe_command($abs);
+            return $abs if $abs = MM->maybe_command($abs);
         }
-        return wantarray ? @possible : $possible[0];
     }
     sub run { return !system(join ' ', @_); }
 
@@ -60,17 +58,51 @@ package inc::MBX::Alien::FLTK::Utility;
         $file =~ m[^(.*)(?:\..*)$] or return @_;
         return catpath($vol, $dir, ($1 ? $1 : $file) . '.' . $Config{'so'});
     }
-    sub _path { File::Spec->catdir(@_) }
-
-    sub _realpath {
-        eval { Cwd::realpath(File::Spec->canonpath(shift)) };
-    }
+    sub _path  { File::Spec->catdir(@_) }
     sub _abs   { File::Spec->rel2abs(@_) }
     sub _rel   { File::Spec->abs2rel(@_) }
-    sub _file  { File::Basename::basename(shift) }
-    sub _dir   { File::Basename::dirname(shift || '') }
+    sub _file  { File::Basename::fileparse(shift); }
+    sub _dir   { File::Basename::dirname(shift); }
     sub _split { File::Spec->splitpath(@_) }
-    sub _cwd   { Cwd::cwd(); }
+
+    sub find_lib {
+        my ($find, $dir) = @_;
+        no warnings 'File::Find';
+        $find =~ s[([\+\*\.])][\\$1]g;
+        $dir ||= $Config{'libpth'};
+        $dir = canonpath($dir);
+        my $lib;
+        find(
+            sub {
+                $lib = canonpath(rel2abs($File::Find::dir))
+                    if $_ =~ qr[lib$find$Config{'_a'}];
+            },
+            split ' ',
+            $dir
+        ) if $dir;
+        return $lib;
+    }
+
+    sub find_h {
+        my ($file, $dir) = @_;
+        no warnings 'File::Find';
+        $dir ||= $Config{'incpath'} . ' ' . $Config{'usrinc'};
+        $dir  = canonpath($dir);
+        $file = canonpath($file);
+        my $h;
+        find(
+            {wanted => sub {
+                 return if !-d $_;
+                 $h = canonpath(rel2abs($_))
+                     if -f _path($_, $file);
+             },
+             no_chdir => 1
+            },
+            split ' ',
+            $dir
+        ) if $dir;
+        return $h;
+    }
     1;
 }
 
@@ -96,6 +128,6 @@ Creative Commons Attribution-Share Alike 3.0 License. See
 http://creativecommons.org/licenses/by-sa/3.0/us/legalcode.  For
 clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 
-=for git $Id: Utility.pm dfa6aa4 2010-01-16 21:12:51Z sanko@cpan.org $
+=for git $Id: Utility.pm dc42150 2010-01-17 03:51:57Z sanko@cpan.org $
 
 =cut
